==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/libraries/razorqt/translations/librazorqt_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../addplugindialog/addplugindialog.ui" line="14"/>
        <source>Add plugins</source>
        <translation>Dodaj wtyczki</translation>
    </message>
    <message>
        <location filename="../addplugindialog/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>Szukaj:</translation>
    </message>
    <message>
        <location filename="../addplugindialog/addplugindialog.ui" line="52"/>
        <source>Add plugin</source>
        <translation>Dodaj plugin</translation>
    </message>
    <message>
        <location filename="../addplugindialog/addplugindialog.ui" line="59"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <location filename="../powermanager.cpp" line="91"/>
        <source>Hibernate</source>
        <translation>Hibernuj</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="95"/>
        <source>Suspend</source>
        <translation>Uśpij</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="99"/>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="103"/>
        <source>Shutdown</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="107"/>
        <source>Logout</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="119"/>
        <source>Razor Session Suspend</source>
        <translation>Uśpij</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="120"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Czy jesteś pewien, że chcesz uśpić swój komputer?&lt;p&gt;Przełącza komputer w stan niskiego poboru prądu. Stan systemu nie jest zabezpieczony przed utratą zasilania.</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="131"/>
        <source>Razor Session Hibernate</source>
        <translation>Hibernuj</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="132"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Czy jesteś pewien, że chcesz zahibernować swój komputer?&lt;p&gt;Przełącza komputer w stan niskiego poboru prądu. Stan systemu jest zabezpieczony przed utratą zasilania.</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="143"/>
        <source>Razor Session Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="144"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Czy jesteś pewien, że chcesz ponownie uruchomić swój komputer?&lt;p&gt;Cała niezapisana praca zostanie utracona...</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="155"/>
        <source>Razor Session Shutdown</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="156"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Czy jesteś pewien, że chcesz wyłączyć swój komputer?&lt;p&gt;Cała niezapisana praca zostanie utracona...</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="167"/>
        <source>Razor Session Logout</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="168"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Czy jesteś pewien, że chcesz się wylogować?&lt;p&gt;Cała niezapisana praca zostanie utracona...</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="180"/>
        <location filename="../powermanager.cpp" line="185"/>
        <source>Razor Power Manager Error</source>
        <translation>Błąd zarządzania energią</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="180"/>
        <source>Hibernate failed.</source>
        <translation>Hibernacja nie powiodła się.</translation>
    </message>
    <message>
        <location filename="../powermanager.cpp" line="185"/>
        <source>Suspend failed.</source>
        <translation>Uśpienie nie powiodło się.</translation>
    </message>
</context>
<context>
    <name>RazorShortcutButton</name>
    <message>
        <location filename="../razorshortcutbutton.cpp" line="46"/>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <location filename="../razorshortcutbutton.cpp" line="158"/>
        <source>None</source>
        <translation>Brak</translation>
    </message>
</context>
<context>
    <name>ScreenSaver</name>
    <message>
        <location filename="../screensaver.cpp" line="47"/>
        <source>Lock Screen</source>
        <translation>Zablokuj ekran</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="66"/>
        <location filename="../screensaver.cpp" line="74"/>
        <location filename="../screensaver.cpp" line="82"/>
        <location filename="../screensaver.cpp" line="94"/>
        <location filename="../screensaver.cpp" line="102"/>
        <location filename="../screensaver.cpp" line="110"/>
        <location filename="../screensaver.cpp" line="119"/>
        <source>Screen Saver Activation Error</source>
        <translation>Błąd podczas aktywacji wygaszacza ekranu</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="67"/>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. xdg-screensaver nie uruchamia się (crash).</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="75"/>
        <source>An error occurred starting screensaver. xdg-screensaver is not installed correctly.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. xdg-screensaver nie jest poprawnie zainstalowany.</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="83"/>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. xdg-screensaver nie może zostać uruchomiony.</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="95"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. Błąd składni argumentów xdg-screensaver.</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="103"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. Upewnij się, że xdg-screensaver jest zainstalowany oraz uruchomiony.</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="111"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. Akcja &quot;aktywacja&quot; zawiodła. Upewnij się, że xdg-screensaver jest zainstalowany oraz uruchomiony.</translation>
    </message>
    <message>
        <location filename="../screensaver.cpp" line="120"/>
        <source>An error occurred starting screensaver. Unkown error - undocumented return value from xdg-screensaver=%1.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. Nieznany błąd - nieznana wartość zwrócona przez xdg-screensaver=%1.</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <location filename="../aboutdlg.ui" line="14"/>
        <source> About Razor</source>
        <translation>O Razor</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/libraries/razorqt/translations/librazorqt_pl_PL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl_PL" version="2.0">
<context>
    <name>AddPluginDialog</name>
    <message>
        <source>Add plugins</source>
        <translation>Dodaj wtyczki</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Szukaj:</translation>
    </message>
    <message>
        <source>Add plugin</source>
        <translation>Dodaj plugin</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <source>Hibernate</source>
        <translation>Hibernuj</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uśpij</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <source>Razor Session Suspend</source>
        <translation>Uśpij</translation>
    </message>
    <message>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Czy jesteś pewien, że chcesz uśpić swój komputer?&lt;p&gt;Przełącza komputer w stan niskiego poboru prądu. Stan systemu nie jest zabezpieczony przed utratą zasilania.</translation>
    </message>
    <message>
        <source>Razor Session Hibernate</source>
        <translation>Hibernuj</translation>
    </message>
    <message>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Czy jesteś pewien, że chcesz zahibernować swój komputer?&lt;p&gt;Przełącza komputer w stan niskiego poboru prądu. Stan systemu jest zabezpieczony przed utratą zasilania.</translation>
    </message>
    <message>
        <source>Razor Session Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Czy jesteś pewien, że chcesz ponownie uruchomić swój komputer?&lt;p&gt;Cała niezapisana praca zostanie utracona...</translation>
    </message>
    <message>
        <source>Razor Session Shutdown</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Czy jesteś pewien, że chcesz wyłączyć swój komputer?&lt;p&gt;Cała niezapisana praca zostanie utracona...</translation>
    </message>
    <message>
        <source>Razor Session Logout</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Czy jesteś pewien, że chcesz się wylogować?&lt;p&gt;Cała niezapisana praca zostanie utracona...</translation>
    </message>
    <message>
        <source>Razor Power Manager Error</source>
        <translation>Błąd zarządzania energią</translation>
    </message>
    <message>
        <source>Hibernate failed.</source>
        <translation>Hibernacja nie powiodła się.</translation>
    </message>
    <message>
        <source>Suspend failed.</source>
        <translation>Uśpienie nie powiodło się.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Power Manager Error</source>
        <translation>Błąd Menadżera Zasilania</translation>
    </message>
    <message>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface jest nieprawidłowy</translation>
    </message>
    <message>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Błąd menadżera zasilania (D-BUS call)</translation>
    </message>
</context>
<context>
    <name>RazorAboutDLGPrivate</name>
    <message>
        <source>Version: %1</source>
        <translation>Wersja: %1</translation>
    </message>
    <message>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <translation>Zaawansowany, łatwy w obsłudze i szybki pulpit bazujący na Qt.</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <translation>Copyright: %1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <translation>Strona: %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <translation>Licencja: %1</translation>
    </message>
    <message>
        <source>Razor-qt is developed by the &lt;a %1&gt;Razor-qt Team and contributors&lt;/a&gt; on Github.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Special thanks to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Razor-qt is translated into many languages thanks to the work of the translation teams all over the world.</source>
        <translation>Razor-qt jest dostępny w wielu jeżykach dzięki wspanialej pracy ekip tłumaczy z całego świata.</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>&lt;b&gt;Razor Desktop Toolbox - Technical Info&lt;/b&gt;</source>
        <translation>&lt;b&gt;Razor Desktop - Informacje Techniczne&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
    <message>
        <source>Qt</source>
        <translation>Qt</translation>
    </message>
    <message>
        <source>Debug Build</source>
        <translation>Debug Build</translation>
    </message>
    <message>
        <source>System Configuration</source>
        <translation>Konfiguracja Systemu</translation>
    </message>
    <message>
        <source>Share Directory</source>
        <translation>Udostępniany folder</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Tłumaczenia</translation>
    </message>
    <message>
        <source>&lt;b&gt;User Directories&lt;/b&gt;</source>
        <translation>&lt;b&gt;Katalog Użytkownika&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Xdg Data Home</source>
        <translation>Xdg Ścieżka Dostępu Plików</translation>
    </message>
    <message>
        <source>Xdg Config Home</source>
        <translation>Xdg Ścieżka Dostępu Konfiguracji</translation>
    </message>
    <message>
        <source>Xdg Data Dirs</source>
        <translation>Xdg Katalogi Plików</translation>
    </message>
    <message>
        <source>Xdg Cache Home</source>
        <translation>Xdg Ścieżka Dostępu Cache</translation>
    </message>
    <message>
        <source>Xdg Runtime Home</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Xdg Autostart Dirs</source>
        <translation>Xdg Katalogi Autouruchamiania</translation>
    </message>
    <message>
        <source>Xdg Autostart Home</source>
        <translation>Xdg Ścieżka Dostępu Autostart</translation>
    </message>
</context>
<context>
    <name>RazorConfigDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Okno dialogowe</translation>
    </message>
</context>
<context>
    <name>RazorNotificationPrivate</name>
    <message>
        <source>Notifications Fallback</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RazorShortcutButton</name>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
</context>
<context>
    <name>ScreenSaver</name>
    <message>
        <source>Lock Screen</source>
        <translation>Zablokuj ekran</translation>
    </message>
    <message>
        <source>Screen Saver Activation Error</source>
        <translation>Błąd podczas aktywacji wygaszacza ekranu</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started due its crash.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. xdg-screensaver nie uruchamia się (crash).</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver is not installed correctly.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. xdg-screensaver nie jest poprawnie zainstalowany.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. xdg-screensaver cannot be started.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. xdg-screensaver nie może zostać uruchomiony.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. Błąd składni argumentów xdg-screensaver.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. Upewnij się, że xdg-screensaver jest zainstalowany oraz uruchomiony.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Wystąpił błąd podczas uruchamiania wygaszacza ekranu. Akcja &quot;aktywacja&quot; zawiodła. Upewnij się, że xdg-screensaver jest zainstalowany oraz uruchomiony.</translation>
    </message>
    <message>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver=%1.</source>
        <translation>Wystąpił błąd podczas wywołania wygaszacza ekranu. Nieznany błąd - nieudokumentowany zwrot wartości z xdg-screensaver=%1.</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source> About Razor</source>
        <translation>O Razor</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Autorzy</translation>
    </message>
    <message>
        <source>Thanks</source>
        <translation>Dzięki</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Tłumaczenia</translation>
    </message>
    <message>
        <source>Technical Info</source>
        <translation>Informacje Techniczne</translation>
    </message>
</context>
</TS>
